@@ -11,6 +11,7 @@ from .terminal_theme import DEFAULT_TERMINAL_THEME
 
 if TYPE_CHECKING:  # pragma: no cover
     from .terminal_theme import TerminalTheme
+    from .text import Text
 
 
 WINDOWS = platform.system() == "Windows"
@@ -268,17 +269,20 @@ class Color(NamedTuple):
     triplet: Optional[ColorTriplet] = None
     """A triplet of color components, if an RGB color."""
 
-    def __str__(self) -> str:
-        """Render the color to the terminal."""
-        attrs = self.get_ansi_codes(foreground=True)
-        return (
-            f"\x1b[{';'.join(attrs)}m⬤  \x1b[0m"
-            f"<color {self.name!r} ({self.type.name.lower()})>"
-        )
-
     def __repr__(self) -> str:
         return f"<color {self.name!r} ({self.type.name.lower()})>"
 
+    def __rich__(self) -> "Text":
+        """Dispays the actual color if Rich printed."""
+        from .text import Text
+        from .style import Style
+
+        return Text.assemble(
+            f"<color {self.name!r} ({self.type.name.lower()})",
+            ("⬤", Style(color=self)),
+            " >",
+        )
+
     @property
     def system(self) -> ColorSystem:
         """Get the native color system for this color."""
@@ -327,6 +331,22 @@ class Color(NamedTuple):
             assert self.number is None
             return theme.foreground_color if foreground else theme.background_color
 
+    @classmethod
+    def from_ansi(cls, number: int) -> "Color":
+        """Create a Color number from it's 8-bit ansi number.
+
+        Args:
+            number (int): A number between 0-255 inclusive.
+
+        Returns:
+            Color: A new Color instance.
+        """
+        return cls(
+            name=f"color({number})",
+            type=(ColorType.STANDARD if number < 16 else ColorType.EIGHT_BIT),
+            number=number,
+        )
+
     @classmethod
     def from_triplet(cls, triplet: "ColorTriplet") -> "Color":
         """Create a truecolor RGB color from a triplet of values.
@@ -339,6 +359,20 @@ class Color(NamedTuple):
         """
         return cls(name=triplet.hex, type=ColorType.TRUECOLOR, triplet=triplet)
 
+    @classmethod
+    def from_rgb(cls, red: float, green: float, blue: float) -> "Color":
+        """Create a truecolor from three color components in the range(0->255).
+
+        Args:
+            red (float): Red component in range 0-255.
+            green (float): Green component in range 0-255.
+            blue (float): Blue component in range 0-255.
+
+        Returns:
+            Color: A new color object.
+        """
+        return cls.from_triplet(ColorTriplet(int(red), int(green), int(blue)))
+
     @classmethod
     def default(cls) -> "Color":
         """Get a Color instance representing the default color.
@@ -437,10 +471,8 @@ class Color(NamedTuple):
         # Convert to 8-bit color from truecolor color
         if system == ColorSystem.EIGHT_BIT and self.system == ColorSystem.TRUECOLOR:
             assert self.triplet is not None
-
             red, green, blue = self.triplet.normalized
             _h, l, s = rgb_to_hls(red, green, blue)
-
             # If saturation is under 10% assume it is grayscale
             if s < 0.1:
                 gray = round(l * 25.0)
@@ -532,7 +564,7 @@ if __name__ == "__main__":  # pragma: no cover
         if color_number < 16:
             table.add_row(color_cell, f"{color_number}", Text(f'"{name}"'))
         else:
-            color = EIGHT_BIT_PALETTE[color_number]
+            color = EIGHT_BIT_PALETTE[color_number]  # type: ignore
             table.add_row(
                 color_cell, str(color_number), Text(f'"{name}"'), color.hex, color.rgb
             )
