@@ -203,6 +203,7 @@ class Syntax(JupyterMixin):
         tab_size (int, optional): Size of tabs. Defaults to 4.
         word_wrap (bool, optional): Enable word wrapping.
         background_color (str, optional): Optional background color, or None to use theme color. Defaults to None.
+        indent_guides (bool, optional): Show indent guides. Defaults to False.
     """
 
     _pygments_style_class: Type[PygmentsStyle]
@@ -235,6 +236,7 @@ class Syntax(JupyterMixin):
         tab_size: int = 4,
         word_wrap: bool = False,
         background_color: str = None,
+        indent_guides: bool = False,
     ) -> None:
         self.code = code
         self.lexer_name = lexer_name
@@ -247,6 +249,7 @@ class Syntax(JupyterMixin):
         self.tab_size = tab_size
         self.word_wrap = word_wrap
         self.background_color = background_color
+        self.indent_guides = indent_guides
 
         self._theme = self.get_theme(theme)
 
@@ -265,13 +268,13 @@ class Syntax(JupyterMixin):
         tab_size: int = 4,
         word_wrap: bool = False,
         background_color: str = None,
+        indent_guides: bool = False,
     ) -> "Syntax":
         """Construct a Syntax object from a file.
 
         Args:
             path (str): Path to file to highlight.
             encoding (str): Encoding of file.
-            lexer_name (str): Lexer to use (see https://pygments.org/docs/lexers/)
             theme (str, optional): Color theme, aka Pygments style (see https://pygments.org/docs/styles/#getting-a-list-of-available-styles). Defaults to "emacs".
             dedent (bool, optional): Enable stripping of initial whitespace. Defaults to True.
             line_numbers (bool, optional): Enable rendering of line numbers. Defaults to False.
@@ -282,6 +285,7 @@ class Syntax(JupyterMixin):
             tab_size (int, optional): Size of tabs. Defaults to 4.
             word_wrap (bool, optional): Enable word wrapping of code.
             background_color (str, optional): Optional background color, or None to use theme color. Defaults to None.
+            indent_guides (bool, optional): Show indent guides. Defaults to False.
 
         Returns:
             [Syntax]: A Syntax object that may be printed to the console
@@ -319,6 +323,7 @@ class Syntax(JupyterMixin):
             tab_size=tab_size,
             word_wrap=word_wrap,
             background_color=background_color,
+            indent_guides=indent_guides,
         )
 
     def _get_base_style(self) -> Style:
@@ -354,7 +359,7 @@ class Syntax(JupyterMixin):
 
         base_style = self._get_base_style()
         justify: JustifyMethod = (
-            "default" if base_style.transaprent_background else "left"
+            "default" if base_style.transparent_background else "left"
         )
 
         text = Text(
@@ -402,7 +407,7 @@ class Syntax(JupyterMixin):
     def _get_number_styles(self, console: Console) -> Tuple[Style, Style, Style]:
         """Get background, number, and highlight styles for line numbers."""
         background_style = self._get_base_style()
-        if background_style.transaprent_background:
+        if background_style.transparent_background:
             return Style.null(), Style(dim=True), Style.null()
         if console.color_system in ("256", "truecolor"):
             number_style = Style.chain(
@@ -429,7 +434,7 @@ class Syntax(JupyterMixin):
     def __rich_console__(
         self, console: Console, options: ConsoleOptions
     ) -> RenderResult:
-        transparent_background = self._get_base_style().transaprent_background
+        transparent_background = self._get_base_style().transparent_background
         code_width = (
             (options.max_width - self._numbers_column_width - 1)
             if self.code_width is None
@@ -440,6 +445,21 @@ class Syntax(JupyterMixin):
         text = self.highlight(code)
         text.remove_suffix("\n")
         text.expand_tabs(self.tab_size)
+
+        (
+            background_style,
+            number_style,
+            highlight_number_style,
+        ) = self._get_number_styles(console)
+
+        if self.indent_guides and not options.ascii_only:
+            style = (
+                self._get_base_style()
+                + self._theme.get_style_for_token(Comment)
+                + Style(dim=True)
+            )
+            text = text.with_indent_guides(self.tab_size, style=style)
+
         if not self.line_numbers:
             # Simple case of just rendering text
             yield from console.render(text, options=options.update(width=code_width))
@@ -455,18 +475,12 @@ class Syntax(JupyterMixin):
         numbers_column_width = self._numbers_column_width
         render_options = options.update(width=code_width)
 
-        (
-            background_style,
-            number_style,
-            highlight_number_style,
-        ) = self._get_number_styles(console)
-
         highlight_line = self.highlight_lines.__contains__
         _Segment = Segment
         padding = _Segment(" " * numbers_column_width + " ", background_style)
         new_line = _Segment("\n")
 
-        line_pointer = "❱ "
+        line_pointer = "> " if options.legacy_windows else "❱ "
 
         for line_no, line in enumerate(lines, self.start_line + line_offset):
             if self.word_wrap:
@@ -507,11 +521,17 @@ class Syntax(JupyterMixin):
 if __name__ == "__main__":  # pragma: no cover
 
     import argparse
+    import sys
 
     parser = argparse.ArgumentParser(
         description="Render syntax to the console with Rich"
     )
-    parser.add_argument("path", metavar="PATH", help="path to file")
+    parser.add_argument(
+        "path",
+        metavar="PATH",
+        nargs="?",
+        help="path to file",
+    )
     parser.add_argument(
         "-c",
         "--force-color",
@@ -520,6 +540,14 @@ if __name__ == "__main__":  # pragma: no cover
         default=None,
         help="force color for non-terminals",
     )
+    parser.add_argument(
+        "-i",
+        "--indent-guides",
+        dest="indent_guides",
+        action="store_true",
+        default=False,
+        help="display indent guides",
+    )
     parser.add_argument(
         "-l",
         "--line-numbers",
@@ -561,17 +589,37 @@ if __name__ == "__main__":  # pragma: no cover
         default=None,
         help="Overide background color",
     )
+    parser.add_argument(
+        "-x",
+        "--lexer",
+        default="default",
+        dest="lexer_name",
+        help="Lexer name",
+    )
     args = parser.parse_args()
 
     from rich.console import Console
 
     console = Console(force_terminal=args.force_color, width=args.width)
 
-    syntax = Syntax.from_path(
-        args.path,
-        line_numbers=args.line_numbers,
-        word_wrap=args.word_wrap,
-        theme=args.theme,
-        background_color=args.background_color,
-    )
+    if not args.path or args.path == "-":
+        code = sys.stdin.read()
+        syntax = Syntax(
+            code=code,
+            lexer_name=args.lexer_name,
+            line_numbers=args.line_numbers,
+            word_wrap=args.word_wrap,
+            theme=args.theme,
+            background_color=args.background_color,
+            indent_guides=args.indent_guides,
+        )
+    else:
+        syntax = Syntax.from_path(
+            args.path,
+            line_numbers=args.line_numbers,
+            word_wrap=args.word_wrap,
+            theme=args.theme,
+            background_color=args.background_color,
+            indent_guides=args.indent_guides,
+        )
     console.print(syntax, soft_wrap=args.soft_wrap)
